﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.IO;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;

namespace Cvicenie6b
{
    public partial class Form1 : Form
    {
        List<Book> books = new List<Book>();

        public Form1()
        {
            InitializeComponent();
        }

        private void newToolStripMenuItem_Click(object sender, EventArgs e)
        {
            books.Clear();
            listView1.Items.Clear();
        }

        private void addBookToolStripMenuItem_Click(object sender, EventArgs e)
        {
            AddForm addForm = new AddForm();
            if (addForm.ShowDialog() == DialogResult.OK)
            {
                Book book = addForm.book;
                books.Add(book);
                listView1.Items.Add(book.ToString());
            }
        }

        private void saveToolStripMenuItem_Click(object sender, EventArgs e)
        {
            SaveFileDialog dialog = new SaveFileDialog();
            dialog.Filter = "CSV File (*.csv)|*.csv";
            if (dialog.ShowDialog() != DialogResult.OK)
            {
                return;
            }
            StreamWriter writer = null;
            try
            {
                writer = new StreamWriter(dialog.FileName);
                foreach (Book book in books)
                {
                    writer.WriteLine(book.ToCSVString());
                }
            }
            catch
            {
                MessageBox.Show("Can't save data", "Error",
                    MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
            finally
            {
                if (writer != null)
                {
                    writer.Close();
                }
            }
        }

        private void openToolStripMenuItem_Click(object sender, EventArgs e)
        {
            OpenFileDialog dialog = new OpenFileDialog();
            dialog.Filter = "CSV File (*.csv)|*.csv";
            if (dialog.ShowDialog() != DialogResult.OK)
            {
                return;
            }

            books.Clear();
            listView1.Items.Clear();
            StreamReader reader = null;
            try
            {
                reader = new StreamReader(dialog.FileName);
                String line;
                while ((line = reader.ReadLine()) != null)
                {
                    String[] parts = line.Split(';');
                    Book book = new Book(parts[0], parts[1],
                        Int32.Parse(parts[2]));
                    books.Add(book);
                    listView1.Items.Add(book.ToString());
                }
            }
            catch
            {
                MessageBox.Show("Can't load data", "Error",
                    MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
            finally
            {
                if (reader != null)
                {
                    reader.Close();
                }
            }
        }

        private void removeBookToolStripMenuItem_Click(object sender, EventArgs e)
        {
            if (listView1.SelectedIndices.Count == 0)
            {
                MessageBox.Show("No item selected", "Warning", 
                    MessageBoxButtons.OK, MessageBoxIcon.Warning);
            }
            else
            {
                int index = listView1.SelectedIndices[0];
                listView1.Items.RemoveAt(index);
                books.RemoveAt(index);
            }
        }

        private void listView1_SelectedIndexChanged(object sender, EventArgs e)
        {
            if (listView1.SelectedIndices.Count == 0)
            {
                removeBookToolStripMenuItem.Enabled = false;
            }
            else
            {
                removeBookToolStripMenuItem.Enabled = true;
            }
        }

        private void editBookToolStripMenuItem_Click(object sender, EventArgs e)
        {
            int index = listView1.SelectedIndices[0];
            Book book = books[index];
            AddForm editForm = new AddForm(book);
            if (editForm.ShowDialog() == DialogResult.OK)
            {
                books.RemoveAt(index);
                listView1.Items.RemoveAt(index);
                books.Add(editForm.book);
                listView1.Items.Add(editForm.book.ToString());
            }
        }
    }
}
